User-centric changelog
======================

**1.1.0 --- TBA**

**1.0.5 --- 2015-05-02**

 * Fixed project documentation typos, added the ``AUTHORS`` file.
 * Added support for ``pyfftw`` for increased performance.
 * Improved integration with MS Windows.
 * Fixed an install bug #18 that occured when dependencies were not met at install-time.
 * Added documentation for Python constraint interface #15

**1.0.4 --- 2015-03-03**

 * Increased robustness of the tiling algorithm (i.e. when matching small subjects against large templates).
 * Improved regression tests.
 * Fixed project description typo.

**1.0.3 --- 2015-02-22**

  * Fixed the ``MANIFEST.in`` so the package is finally ``easy_install``-able.
  * Added the release check script stub.
  * Updated install docs.

**1.0.2 --- 2015-02-21**

  * Documentation and setup.py fixes.

**1.0.1 --- 2015-02-19**
  
  * Real debut on PyPi.
  * Fixed some minor issues with setup.py and docs.

**1.0.0 --- 2015-02-19**
  
  Beginning of the changelog.

  * Debut on PyPi
